---
Summary: Allow underline header styles
Status: Ready
---

# Description

In addition to the supported `#` header styles, markdown supports header styles
underlined with `---` or `===`. We need to recognise those as headings of
fields.

Example

```markdown
## Field Name

Value of field.
```

# Cucumber

GIVEN line of text with more than 3 `-` or `=` characters underneath it
WHEN the line is parsed
THEN it is treated in the same way as a `#` styled heading.
